@@ -37,6 +37,8 @@ void
 PgnParser::Init ()
 {
     ErrorBuffer = new DString;
+    CharConverter = NULL;
+    CharDetector = NULL;
     Reset();
 }
 
@@ -46,9 +48,7 @@ PgnParser::Reset()
     UnGetCount = 0;
     NumErrors = 0;
     BytesSeen = 0;
-#ifndef WINCE
     ErrorFile = NULL;
-#endif
     LineCounter = 0;
     GameCounter = 0;
     StorePreGameText = true;
@@ -56,8 +56,6 @@ PgnParser::Reset()
     ResultWarnings = true;
     NewlinesToSpaces = true;
     NumIgnoredTags = 0;
-    CharConverter = NULL;
-    CharDetector = NULL;
 }
 
 void
@@ -187,16 +185,6 @@ void
 PgnParser::LogError (const char * errMessage, const char * text)
 {
     NumErrors++;
-#ifdef WINCE
-//     if (ErrorFile != NULL) {
-        //fprintf (ErrorFile, "%s%s [line %u]\n", errMessage, text, LineCounter);
-        if (InFile != NULL) {
-            printf ("%s:", InFile->GetFileName());
-        }
-        printf ("%u: %s%s\n", LineCounter, errMessage, text);
-        return;
-//     }
-#else
     if (ErrorFile != NULL) {
         //fprintf (ErrorFile, "%s%s [line %u]\n", errMessage, text, LineCounter);
         if (InFile != NULL) {
@@ -205,7 +193,6 @@ PgnParser::LogError (const char * errMessage, const char * text)
         fprintf (ErrorFile, "(game %u, line %u) %s%s\n", GameCounter, LineCounter, errMessage, text);
         return;
     }
-#endif
     ErrorBuffer->Append ("(game ", GameCounter);
     ErrorBuffer->Append (", line ", LineCounter, ") ");
     ErrorBuffer->Append (errMessage, text, "\n");
@@ -378,6 +365,9 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
 
     // Now decide what to add to the game based on this tag:
     if (strEqual (tag, "White")) {
+        // The White, Black, Site, Event, Round tags should not be empty
+        // (Date and Result should also have values, but these will be set after ExtractPgnTag returns)
+        if (length == 0) { return ERROR_PGNTagNull; }
 #ifdef STANDARD_PLAYER_NAMES
         standardPlayerName (value);
 #endif
@@ -399,6 +389,7 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
         game->SetWhiteStr (value);
 
     } else if (strEqual (tag, "Black")) {
+        if (length == 0) { return ERROR_PGNTagNull; }
 #ifdef STANDARD_PLAYER_NAMES
         standardPlayerName (value);
 #endif
@@ -420,12 +411,15 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
         game->SetBlackStr (value);
 
     } else if (strEqual (tag, "Event")) {
+        if (length == 0) { return ERROR_PGNTagNull; }
         game->SetEventStr (value);
 
     } else if (strEqual (tag, "Site")) {
+        if (length == 0) { return ERROR_PGNTagNull; }
         game->SetSiteStr (value);
 
     } else if (strEqual (tag, "Round")) {
+        if (length == 0) { return ERROR_PGNTagNull; }
         game->SetRoundStr (value);
 
     } else if (strEqual (tag, "Result")) {
@@ -526,7 +520,7 @@ PgnParser::GetComment (char * buffer, uint bufSize)
     int startLine = LineCounter;
     ch = GetChar();
 
-	 ASSERT(bufSize > 0);
+    ASSERT(bufSize > 0);
 
     while (ch != EndChar  &&  ch != '}') {
         if (NewlinesToSpaces  &&  ch == '\n') { ch = ' '; }
@@ -1121,7 +1115,7 @@ PgnParser::ParseMoves (Game * game, char * buffer, uint bufSize)
                     char tempStr [500];
                     // Add an error comment to the game:
                     snprintf (tempStr, sizeof(tempStr), "Error reading move: %s", buffer);
-                    game->SetMoveComment (tempStr);
+                    game->AppendMoveComment (tempStr);
                     snprintf (tempStr, sizeof(tempStr), "Error reading move in game %s - %s, %u: ",
                              game->GetWhiteStr(), game->GetBlackStr(),
                              date_GetYear (game->GetDate()));
@@ -1166,8 +1160,11 @@ PgnParser::ParseMoves (Game * game, char * buffer, uint bufSize)
 
         case TOKEN_Comment:
             GetComment (buffer, bufSize);
+            // We remove extra spaces from comments.
+            // Problem is, this is fine for indented comments (as we'd find in column formatted pgn)
+            // , but not desirable for non-indented comments, where we want to preserve newlines (for eg)
             strSingleSpace (buffer);
-            game->SetMoveComment (buffer);
+            game->AppendMoveComment (buffer);
             break;
 
         case TOKEN_LineComment:
@@ -1236,17 +1233,10 @@ PgnParser::ParseMoves (Game * game, char * buffer, uint bufSize)
 errorT
 PgnParser::ParseGame (Game * game)
 {
-#ifdef WINCE
-    char * buffer = my_Tcl_Alloc(sizeof( char [MAX_COMMENT_SIZE]));
-    uint preGameTextLength = 0;
-
-    char * preGameTextBuffer = my_Tcl_Alloc(sizeof(char [MAX_COMMENT_SIZE]));
-#else
     char * buffer = new char [MAX_COMMENT_SIZE];
     uint preGameTextLength = 0;
 
     char * preGameTextBuffer = new char [MAX_COMMENT_SIZE];
-#endif
 
     GameCounter++;
     errorT err = ERROR_NotFound;
@@ -1266,7 +1256,9 @@ PgnParser::ParseGame (Game * game)
                 }
                 ParseMode = PARSE_Header;
             }
-            if (ExtractPgnTag (buffer, game) != OK) {
+            errorT pgnRes = ExtractPgnTag (buffer, game);
+            // Don't throw errors for null pgn tags - too verbose
+            if (pgnRes != OK && pgnRes != ERROR_PGNTagNull) {
                 LogError ("Error reading tag: ", buffer);
             }
 
@@ -1298,21 +1290,14 @@ PgnParser::ParseGame (Game * game)
 
         token = GetNextToken (buffer, MAX_COMMENT_SIZE);
     }
-#ifdef WINCE
-    my_Tcl_Free( buffer );
-    my_Tcl_Free( preGameTextBuffer );
-#else
     delete[] buffer;
     delete[] preGameTextBuffer;
-#endif
 
     if (err != ERROR_NotFound && CharDetector)
     {
         CharDetector->finish();
 
-        if (CharDetector->charset() == CharsetDetector::UTF8)
-            MapChessBaseFigurine(game);
-        else
+        if (CharDetector->charset() != CharsetDetector::UTF8)
             DoCharsetConversion(game);
 
         CharDetector->reset();
@@ -1371,23 +1356,6 @@ static Pair GetSetTbl[5] =
 };
 
 
-void
-PgnParser::MapChessBaseFigurine(Game * game)
-{
-    // Convert standard tags.
-
-    for (unsigned i = 0; i < sizeof(::GetSetTbl)/sizeof(::GetSetTbl[0]); ++i)
-    {
-        Pair const& p = ::GetSetTbl[i];
-
-        char * str((game->*p.getter)());
-
-        if (!CharsetConverter::isAscii(str))
-            (game->*p.setter)(CharsetConverter::mapChessBaseFigurineToUTF8(str).c_str());
-    }
-}
-
-
 void
 PgnParser::DoCharsetConversion(Game * game)
 {
