@@ -1,10 +1,10 @@
-
-####################
-# File finder window
+###
+### finder.tcl
+###
 
 set ::file::finder::data(stop) 0
 
-### Open/Close the finder
+### Open/Close the file finder
 
 proc ::file::finder::Open {} {
   set w .finder
@@ -26,7 +26,7 @@ proc ::file::finder::Open {} {
 
   $w.menu add cascade -label FinderFile -menu $w.menu.file
   menu $w.menu.file
-  $w.menu.file add command -label {Open Directory} -command ::file::finder::OpenDIR
+  $w.menu.file add command -label "$::tr(FinderDirOpen)" -command ::file::finder::OpenDIR
   $w.menu.file add command -label FinderFileClose -command "destroy $w"
 
   bind $w <Control-o> ::file::finder::OpenDIR
@@ -64,7 +64,7 @@ proc ::file::finder::Open {} {
   frame $w.t -relief flat
   frame $w.b
   text $w.t.text -width 70 -height 25 -font font_Small -wrap none \
-      -fg black  -yscrollcommand "$w.t.ybar set" -setgrid 1 \
+      -yscrollcommand "$w.t.ybar set" -setgrid 1 \
       -cursor top_left_arrow
   scrollbar $w.t.ybar -command "$w.t.text yview" -width 12
   $w.t.text tag configure Up -foreground brown
@@ -78,6 +78,8 @@ proc ::file::finder::Open {} {
   $w.t.text tag configure center -justify center
   set xwidth [font measure [$w.t.text cget -font] "x"]
   set tablist {}
+  # tablist is used in spacing *both* the dirlist (at top) and the file details columns
+  # ... but this should be changed so we have more room in the filelist 'name' column S.A
   #                      name   size   type   date   path
   foreach {tab justify} {       29 r   31 l   50 r   55 l} {
     set tabwidth [expr {$xwidth * $tab} ]
@@ -89,12 +91,12 @@ proc ::file::finder::Open {} {
   checkbutton $w.b.sub -text [tr FinderFileSubdirs] \
       -variable ::file::finder::data(recurse) -onvalue 1 -offvalue 0 \
       -command ::file::finder::Refresh
-  # the stop button seems broke S.A.
-  dialogbutton $w.b.stop -textvar ::tr(Stop) -command {set finder(stop) 1 }
+  dialogbutton $w.b.stop -textvar ::tr(Stop) -command {set ::file::finder::data(stop) 1 }
   dialogbutton $w.b.help -textvar ::tr(Help) -command {helpWindow Finder}
   dialogbutton $w.b.close -textvar ::tr(Close) -command "destroy $w"
   bind $w <Escape>        "$w.b.close invoke"
   bind $w <Control-slash> "$w.b.close invoke"
+  bindWheeltoFont $w
 
   # Bind left button to close ctxt menu:
   bind $w <ButtonPress-1> {
@@ -134,7 +136,6 @@ proc ::file::finder::Refresh {{newdir ""}} {
   $w.b.help configure -state disabled
   $w.b.sub configure -state disabled
   $w.b.stop configure -state normal
-  catch {grab $w.b.stop}
   $t configure -state normal
   update
 
@@ -154,7 +155,7 @@ proc ::file::finder::Refresh {{newdir ""}} {
     "mod"  { set flist [lsort -integer -decreasing -index 4 $flist] }
   }
 
-  set hc grey85
+  set hc $::rowcolor
   $t delete 1.0 end
   set dcount 0
   # $t insert end [string toupper "$::tr(FinderDirs)\n"] {center bold}
@@ -234,7 +235,7 @@ proc ::file::finder::Refresh {{newdir ""}} {
   foreach i $flist {
     set size [lindex $i 0]
     set type [lindex $i 1]
-    set fname [string range [lindex $i 2] 0 15] ; # limit to 16 chars S.A.
+    set fname [string range [lindex $i 2] 0 23] 
     set path [lindex $i 3]
     # If case path has spaces, they break tag bindings, so use this tag
     set pathtag [string map {{ } _} $path]
@@ -247,7 +248,7 @@ proc ::file::finder::Refresh {{newdir ""}} {
     if {$est} { set esize "~" }
     append esize [::utils::thousands $size]
     $t insert end "$esize\t" f$pathtag
-    $t insert end $type [list $type f$pathtag]
+    $t insert end "$type" [list $type f$pathtag]
     $t insert end "\t[clock format $mtime -format {%d-%m-%Y}]" f$pathtag
     $t insert end "\t" f$pathtag
     set dir [file dirname $path]
@@ -277,17 +278,13 @@ proc ::file::finder::Refresh {{newdir ""}} {
 
   $w.d.label configure -text $data(dir)
 
-  catch {grab release $w.b.stop}
   $w.b.stop configure -state disabled
   $w.b.help configure -state normal
   $w.b.close configure -state normal
   $w.b.sub configure -state normal
   unbusyCursor .
-
 }
-################################################################################
-#
-################################################################################
+
 proc ::file::finder::contextMenu {win fullPath x y} {
 
   update idletasks
@@ -309,15 +306,19 @@ proc ::file::finder::contextMenu {win fullPath x y} {
   tk_popup $mctxt $x $y
 
 }
-################################################################################
-# will backup a base in the form name-date.ext
-################################################################################
+
+### Backup a base in the form name-date.ext
+
 proc ::file::finder::backup { f } {
   set r [file rootname $f]
   set d [clock format [clock seconds] -format "-%Y.%m.%d-%H%M" ]
   set ext [string tolower [file extension $f]]
+
+  busyCursor .
+  update
   if { $ext == ".si4" } {
     if { [catch { file copy "$r.sg4" "$r$d.sg4" ; file copy "$r.sn4" "$r$d.sn4" } err ] } {
+      unbusyCursor .
       tk_messageBox -title Scid -icon error -type ok -message "File copy error $err"
       return
     }
@@ -325,15 +326,15 @@ proc ::file::finder::backup { f } {
   }
 
   if { [catch { file copy "$r[file extension $f]" "$r$d[file extension $f]" } err ] } {
+    unbusyCursor .
     tk_messageBox -title Scid -icon error -type ok -message "File copy error $err"
     return
   }
 
+  unbusyCursor .
   ::file::finder::Refresh
 }
-################################################################################
-#
-################################################################################
+
 proc ::file::finder::copy { f } {
   if {[sc_base slot $f] != 0} {
     tk_messageBox -title Scid -icon error -type ok -message "Close base first" -parent .finder
@@ -357,9 +358,7 @@ proc ::file::finder::copy { f } {
 
   }
 }
-################################################################################
-#
-################################################################################
+
 proc ::file::finder::move { f } {
   if {[sc_base slot $f] != 0} {
     tk_messageBox -title Scid -icon error -type ok -message "Close base first" -parent .finder
@@ -470,10 +469,6 @@ proc ::file::finder::getname {} {
   return "$::tmp"
 }
 
-################################################################################
-#
-################################################################################
-
 proc ::file::finder::delete { f } {
   if {[sc_base slot $f] != 0} {
     tk_messageBox -title Scid -icon error -type ok -message "Close base first" -parent .finder
@@ -490,9 +485,6 @@ proc ::file::finder::delete { f } {
   ::file::finder::Refresh
 }
 
-################################################################################
-#
-################################################################################
 proc ::file::finder::ConfigMenus {{lang ""}} {
   if {! [winfo exists .finder]} { return }
   if {$lang == ""} { set lang $::language }
@@ -521,8 +513,12 @@ proc ::file::finder::GetFiles {dir {len -1}} {
   if {$len < 0} {
     set len [expr {[string length $dir] + 1} ]
   }
-
-  foreach f [glob -nocomplain [file join $dir *]] {
+  set files {}
+  # No read permissions throw errors :(
+  catch {
+    set files [glob -nocomplain [file join $dir *]]
+  }
+  foreach f $files {
     if {[file isdir $f]} {
       lappend dlist $f
     } elseif {[file isfile $f]} {
@@ -564,7 +560,7 @@ proc ::file::finder::GetFiles {dir {len -1}} {
         lappend flist [list $size $type [file tail $rootname] $path $mtime $est]
       }
     }
-    update
+    update idletasks
     if {$data(stop)} { break }
   }
   if {$data(recurse)} {
@@ -580,20 +576,8 @@ proc ::file::finder::GetFiles {dir {len -1}} {
 }
 
 proc ::file::finder::OpenDIR {} {
-  # borrowed from file/maint.tcl
-  set w .finderdir ;#.bdesc
-  if {[winfo exists $w]} { return }
-  toplevel $w
-  wm title $w "Scid: Open"
-  wm withdraw $w
-
-  set font font_Small
-  entry $w.entry -width 50 -relief sunken 
-  pack $w.entry -side top -pady 4
-  frame $w.b
-  dialogbutton $w.b.ok -text OK -command {
-    if {[file isdir [.finderdir.entry get]]} {
-      set dir [.finderdir.entry get]
+  set dir [tk_chooseDirectory -parent .finder -initialdir $::initialDir(file) -title "$::tr(FinderCtxOpen) $::tr(FinderDir)"]
+  if {$dir != ""} {
       # silly hacks to fix up finder bug with "~"
       if {$dir == {~}} {
         set dir $::env(HOME)
@@ -602,19 +586,7 @@ proc ::file::finder::OpenDIR {} {
       }
       ::file::finder::Refresh $dir
     }
-    grab release .finderdir
-    destroy .finderdir
-  }
-  dialogbutton $w.b.cancel -text $::tr(Cancel) -command "grab release $w; destroy $w"
-  pack $w.b -side bottom -fill x
-  pack $w.b.cancel $w.b.ok -side right -padx 2 -pady 2
-  bind $w.entry <Return> "$w.b.ok invoke"
-  bind $w <Escape> "$w.b.cancel invoke"
-  focus $w.entry
-
-  placeWinOverParent $w .finder
-  wm state $w normal
-  wm resizable $w 0 0
-  catch {grab $w}
 }
 
+### end of finder.tcl
+
