@@ -229,6 +229,8 @@ menuText L OptionsVarLineColour "Muunnelman nuolet" 0 {Muunnelman nuolet}
 # ====== TODO To be translated ======
 menuText L OptionsEngineLineColour "Engine Arrows" 0 {Engine arrows}
 menuText L OptionsRowColour "Rivit" 0 {Oletus puu/kirja-rivin vri}
+# ====== TODO To be translated ======
+menuText L OptionsHighlightColour "Highlight" 0 {Default text highlight color}
 menuText L OptionsSwitcherColour "Katkaisin" 0 {Oletus db-valitsijan vri}
 menuText L OptionsProgressColour "Edistymispalkki" 0 {Edistymispalkin oletusvri}
 menuText L OptionsScoreColour "Tulosgrafiikka" 0 {}
@@ -443,6 +445,8 @@ translate L readonly {kirjoitussuojattu}
 translate L altered {muutettu}
 translate L tagsDescript {Listagit (Esimerkiksi: kommentoija "Anand")}
 translate L prevTags {Kyt edellist}
+# ====== TODO To be translated ======
+translate L value {Value}
 
 # Standard error messages:
 translate L ErrNotOpen {Tm ei ole avoin tietokanta.}
@@ -688,6 +692,8 @@ translate L AnnotateBlundersOnly {Kun siirto on mhlys}
 translate L BlundersNotBest {Mhlykset/ei paras siirto}
 translate L AnnotateTitle {Konfiguroi kommentti}
 translate L AnnotateMissedMates {Huomaamatta jneet/lyhyemmt matit}
+# ====== TODO To be translated ======
+translate L AnnotateEnd {At end of game}
 translate L BlundersThreshold {Raja-arvo}
 translate L ScoreFormat {Lopputuloksen formaatti}
 translate L CutOff {Katkaise}
@@ -1116,6 +1122,8 @@ translate L ChangeTextDialog {Enabling text colour globally requires restart.}
 # ====== TODO To be translated ======
 translate L ChangeDockDialog {Changing Docking requires a restart.}
 # ====== TODO To be translated ======
+translate L FontSelectDialog "This is some sample text\nDouble click above to change font, then select 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
+# ====== TODO To be translated ======
 translate L ExitNow {Exit now ?}
 
 # Import window:
@@ -1199,6 +1207,8 @@ translate L OprepTheoryTable {Teoriataulukko}
 translate L OprepTableComment {Luotu %u korkeimman Elo-luvun peleist}
 translate L OprepExtraMoves {Ylimriset huomatussiirrot teoriataulukossa}
 translate L OprepMaxGames {Maksimimr pelej teoriataulukossa}
+# ====== TODO To be translated ======
+translate L OprepMaxLines {Maximum games for statistics}
 translate L OprepViewHTML {Nyt HTML}
 translate L OprepViewLaTeX {Nyt LaTeX}
 
@@ -1304,6 +1314,8 @@ translate L ExportComments {Vie kommentit?}
 translate L ExportVariations {Vie muunnelmat?}
 translate L IndentComments {Sisenn kommentit?}
 translate L IndentVariations {Sisenn muunnelmat?}
+# ====== TODO To be translated ======
+translate L InsertNewlines {Insert newlines every 80 chars?}
 translate L ExportColumnStyle {Sarakkeen tyyli (yksi siirto rivi kohden)?}
 translate L ExportSymbolStyle {Symbolinen huomautustyyli:}
 translate L ExportStripMarks {Poista ruutu/nuoli-merkkikoodit kommenteista?}
@@ -1456,6 +1468,8 @@ translate L WinWonGame {Voita voittopeli}
 translate L Lines {Muunnelmat}
 translate L ConfigureUCIengine {Konfiguroi ohjelma}
 translate L SpecificOpening {Tietty avaus}
+# ====== TODO To be translated ======
+translate L ImportECO {Import ECO}
 translate L StartNewGame {Aloita uusi peli}
 translate L FixedLevel {Mrtty taso}
 translate L Opening {Avaus}
