@@ -265,6 +265,8 @@ menuText N OptionsEngineLineColour "Engine Arrows" 0 {Engine arrows}
 # ====== TODO To be translated ======
 menuText N OptionsRowColour "Rows" 0 {Default tree/book row color}
 # ====== TODO To be translated ======
+menuText N OptionsHighlightColour "Highlight" 0 {Default text highlight color}
+# ====== TODO To be translated ======
 menuText N OptionsSwitcherColour "Switcher" 0 {Default db switcher color}
 # ====== TODO To be translated ======
 menuText N OptionsProgressColour "Progressbar" 0 {Default progressbar color}
@@ -506,6 +508,8 @@ translate N altered {altered}
 translate N tagsDescript {Extra tags (eg: Annotator "Anand")}
 # ====== TODO To be translated ======
 translate N prevTags {Use previous}
+# ====== TODO To be translated ======
+translate N value {Value}
 
 # Standard error messages:
 translate N ErrNotOpen {Deze database is niet geopend.}
@@ -768,6 +772,8 @@ translate N BlundersNotBest {Blunders/Not Best}
 translate N AnnotateTitle {Configureren annotatie}
 # ====== TODO To be translated ======
 translate N AnnotateMissedMates {Missed/shorter mates}
+# ====== TODO To be translated ======
+translate N AnnotateEnd {At end of game}
 translate N BlundersThreshold {Ondergrens}
 # ====== TODO To be translated ======
 translate N ScoreFormat {Score format}
@@ -1215,6 +1221,8 @@ translate N ChangeTextDialog {Enabling text colour globally requires restart.}
 # ====== TODO To be translated ======
 translate N ChangeDockDialog {Changing Docking requires a restart.}
 # ====== TODO To be translated ======
+translate N FontSelectDialog "This is some sample text\nDouble click above to change font, then select 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
+# ====== TODO To be translated ======
 translate N ExitNow {Exit now ?}
 
 # Import window:
@@ -1300,6 +1308,8 @@ translate N OprepTheoryTable {Theorie tabel}
 translate N OprepTableComment {Samengesteld uit de %u partijen met de hoogste Elo classificatie.}
 translate N OprepExtraMoves {Extra zetten in theorie tabel}
 translate N OprepMaxGames {Maximaal aantal partijen in theorie tabel}
+# ====== TODO To be translated ======
+translate N OprepMaxLines {Maximum games for statistics}
 translate N OprepViewHTML { HTML zicht} ;
 translate N OprepViewLaTeX {LaTeX zicht} ;
 
@@ -1406,6 +1416,8 @@ translate N ExportComments {Exporteren commentaar?}
 translate N ExportVariations {Exporteren varianten?}
 translate N IndentComments {Inspringen commentaar?}
 translate N IndentVariations {Inspringen varianten?}
+# ====== TODO To be translated ======
+translate N InsertNewlines {Insert newlines every 80 chars?}
 translate N ExportColumnStyle {Kolomstijl (een zet per regel)?}
 translate N ExportSymbolStyle {Symbolische annotatie stijl:}
 translate N ExportStripMarks {Wis vierkante haken/pijlen markeer codes uit de commentaar?}
@@ -1597,6 +1609,8 @@ translate N Lines {Varianten}
 translate N ConfigureUCIengine {Configureer UCI engine}
 
 translate N SpecificOpening {Specifieke opening}
+# ====== TODO To be translated ======
+translate N ImportECO {Import ECO}
 translate N StartNewGame {Start nieuwe partij}
 translate N FixedLevel {Vast niveau}
 translate N Opening {Opening}
