@@ -90,7 +90,7 @@ menuText B EditPasteBoard "Colar Posicao" 12 \
 
 # Game menu:
 menuText B Game "Jogo" 0
-menuText B GameNew "Limpar Jogo" 0 \
+menuText B GameNew "Novo Jogo" 0 \
   {Limpa o jogo corrente, descartando qualquer alteracao}
 menuText B GameFirst "Primeiro Jogo" 5 {Carrega o primeiro jogo filtrado}
 menuText B GamePrev "Jogo Anterior" 5 {Carrega o jogo anterior}
@@ -269,7 +269,7 @@ menuText B ToolsImportFile "Importa arquivo de jogos PGN..." 7 \
 
 menuText B ToolsStartEngine1 "Iniciar engine 1" 0  {Inicia engine 1}
 menuText B ToolsStartEngine2 "Iniciar engine 2" 0  {Inicia engine 2}
-menuText B ToolsScreenshot "Screenshot bordo" 0
+menuText B ToolsScreenshot "Copia Imagem Tabuleiro" 0
 menuText B Play "Jogar" 0
 menuText B CorrespondenceChess "Xadrez por correspondncia" 0 {Funes para jogar xadrez por correspondncia usando eMail e Xfcc}
 menuText B CCConfigure "Configurar..." 0 {Configura ferramentas externas e configurao geral}
@@ -303,6 +303,7 @@ menuText B OptionsVarLineColour "Setas de Variantes" 0 {Setas de Variantes}
 menuText B OptionsEngineLineColour "Setas do motor" 0 {Setas do motor}
 
 menuText B OptionsRowColour "Linhas" 0 {Cor padrao da linha para arvore/livro}
+menuText B OptionsHighlightColour "Destaque" 0 {Default text highlight color}
 
 menuText B OptionsSwitcherColour "Chaveador" 0 {Cor padrao para o chaveador de base}
 
@@ -360,7 +361,7 @@ menuText B OptionsMovesCoord "Entrada de movimentos por coordenadas" 0 \
 
 menuText B OptionsShowVarPopup "Mostrar janela de variantes" 0 {Liga/Desliga a janela de variantes}  
 
-menuText B OptionsMovesSpace "Add spaces after move number" 0 {Add spaces after move number}  
+menuText B OptionsMovesSpace "Adiciona espacos apos o numero do movimento" 0 {Adiciona espacos apos o numero do movimento}  
 menuText B OptionsMovesKey "Auto completar" 0 \
   {Liga/desliga auto completar a partir do que for digitado}
 menuText B OptionsMovesShowVarArrows "Mostrar Setas para variantes" 0 {Liga/Desliga as setas que mostram movimentos em variantes}
@@ -409,7 +410,7 @@ menuText B OptionsAutoSave "Salva Opcoes ao sair" 0 \
 
 # Help menu:
 menuText B Help "Ajuda" 0
-menuText B HelpContents "Conteudo" 0 {Show the help contents page} 
+menuText B HelpContents "Conteudo" 0 {Mostra a pgina de conteudo da Ajuda} 
 menuText B HelpIndex "Indice" 0 {Indice da Ajuda}
 menuText B HelpGuide "Consulta Rapida" 0 {Mostra a pagina de consulta rapida}
 menuText B HelpHints "Dicas" 0 {Mostra a pagina de dicas}
@@ -547,7 +548,7 @@ translate B Database {Base de dados}
 translate B Filter {Filtro}
 
 translate B Reset {Reiniciar}
-# todo
+# todo - OK
 translate B IgnoreCase {Ignorar maiusc/minusculas}
 translate B noGames {nenhum jogo}
 translate B allGames {todos os jogos}
@@ -564,6 +565,7 @@ translate B altered {alterado}
 translate B tagsDescript {Tags extras (ex: Anotador "Anand")}
 
 translate B prevTags {Use anterior}
+translate B value {Valor}
 
 # Standard error messages:
 translate B ErrNotOpen {Esta base no est aberta.} 
@@ -842,14 +844,15 @@ translate B AnnotateWhite {Apenas para movimentos das Brancas}
 translate B AnnotateBlack {Apenas para movimentos das Pretas}
 translate B AnnotateNotBest {Quando o movimento do jogo nao for o melhor movimento}
 
-translate B AnnotateBlundersOnly {Quando o mivimento for um erro crasso}
+translate B AnnotateBlundersOnly {Quando o movimento for um erro crasso}
 
-translate B BlundersNotBest {Erro crasso/No Melhor}
+translate B BlundersNotBest {Erro crasso/Nao Melhor}
 
 
 translate B AnnotateTitle {Configurar Anotacao}
 
 translate B AnnotateMissedMates {Mates perdidos/menores}
+translate B AnnotateEnd {No fim do jogo}
 translate B BlundersThreshold {Limite}
 
 translate B ScoreFormat {Formato do Score}
@@ -965,7 +968,7 @@ menuText B CrosstabOptColorHyper "Hipertexto" 0
 
 menuText B CrosstabOptTieWin "Tie-Break por vitorias" 1
 
-menuText B CrosstabOptTieHead "Tie-Break by cabeca" 1
+menuText B CrosstabOptTieHead "Tie-Break por cabeca" 1
 # todo
 menuText B CrosstabOptThreeWin "3 Pontos para vitoria" 1
 menuText B CrosstabOptAges "Idade em anos" 0
@@ -1353,6 +1356,7 @@ translate B ClearGameDialog {Este jogo foi alterado.\nVoce quer salva-lo?}
 translate B ExitUnsaved {As bases a seguir tem mudanas nos jogos que no foram salvas. Se voc sair agora, essas mudanas sero perdidas.} 
 translate B ChangeTextDialog {Habilitar cor do texto globalmente exige reinicio.}
 translate B ChangeDockDialog {Alterar a docagem exige reinicio.}
+translate B FontSelectDialog "Este e um texto de exemplo\nDuplo clique acima para mudar a fonte, depois selecione 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
 translate B ExitNow {Sair agora ?}
 
 
@@ -1438,6 +1442,7 @@ translate B OprepTheoryTable {Tabela de Teoria}
 translate B OprepTableComment {Gerada a partir dos %u jogos com rating mais alto.}
 translate B OprepExtraMoves {Movimentos com nota extra na Tabela de Teoria}
 translate B OprepMaxGames {Qtde. Maxima de jogos na tabela de teoria}
+translate B OprepMaxLines {Mximo de jogos para estatisticas}
 translate B OprepViewHTML {Visualizar HTML} 
 translate B OprepViewLaTeX {Visualizar LaTeX} 
 
@@ -1539,7 +1544,7 @@ translate B NoUnusedNames "No h nomes no utilizados, ento o arquivo j est totalm
 
 translate B NoUnusedGames "O arquivo de jogo j est totalmente compactado."
 
-translate B NameFileCompacted {The name file for "[file tail [sc_base filename]]" was compacted.}
+translate B NameFileCompacted {O arquivo de nomes para "[file tail [sc_base filename]]" foi compactado.}
 
 translate B GameFileCompacted {O arquivo de jogos para a base est compactado.}
 
@@ -1555,6 +1560,7 @@ translate B ExportComments {Exportar comentarios?}
 translate B ExportVariations {Exportar variantes?}
 translate B IndentComments {Identar Comentarios?}
 translate B IndentVariations {Identar Variantes?}
+translate B InsertNewlines {Inserir quebras de linha a cada 80 caracteres?}
 translate B ExportColumnStyle {Estilo Coluna (um movimento por linha)?}
 translate B ExportSymbolStyle {Estilo de anotacao simbolica:}
 translate B ExportStripMarks {Remover cdigos de marca de casa/seta dos comentrios?} 
@@ -1585,7 +1591,7 @@ translate B LightSquares {Casas Brancas}
 translate B DarkSquares {Casas Pretas}
 translate B SelectedSquares {Casas selecionadas}
 # todo
-translate B Grid {Grid}
+translate B Grid {Grade}
 translate B Previous {Escolhas}
 translate B WhitePieces {Pecas Brancas}
 translate B BlackPieces {Pecas Pretas}
@@ -1796,6 +1802,7 @@ translate B Lines {Linhas}
 translate B ConfigureUCIengine {Configurar engine UCI}
 
 translate B SpecificOpening {Abertura especifica}
+translate B ImportECO {Importar ECO}
 
 translate B StartNewGame {Iniciar novo jogo}
 
