@@ -281,6 +281,8 @@ menuText S OptionsVarLineColour "Flechas de variacin" 0 {Flechas de variacin}
 # ====== TODO To be translated ======
 menuText S OptionsEngineLineColour "Engine Arrows" 0 {Engine arrows}
 menuText S OptionsRowColour "Filas" 0 {Color predeterminado de la columna de rbol/libro}
+# ====== TODO To be translated ======
+menuText S OptionsHighlightColour "Highlight" 0 {Default text highlight color}
 menuText S OptionsSwitcherColour "Conmutador" 0 {Color del conmutador db predeterminado}
 menuText S OptionsProgressColour "Barra de progreso" 0 {Color predeterminado de la barra de progreso}
 menuText S OptionsScoreColour "Grfico de puntuacin" 0 {}
@@ -309,7 +311,7 @@ menuText S OptionsMovesTranslatePieces "Traducir piezas" 0 {Traducir la primera
 menuText S OptionsMovesHighlightLastMove "Resalta ltima jugada" 0 {Resalta la ltima jugada}
 menuText S OptionsMovesHighlightLastMoveDisplay "Mostrar" 0 {Muestra la ltima jugada iluminada}
 menuText S OptionsMovesHighlightLastMoveWidth "Ancho" 0 {Espesor de la lnea}
-menuText S OptionsMovesHighlightLastMoveColor "Color" 0 {Color de lnea}
+menuText S OptionsMovesHighlightLastMoveColor "Select Color" 0 {Color de lnea}
 # ====== TODO To be translated ======
 menuText S OptionsMovesColorSelected "Color Selected Square" 0 {Color move}
 menuText S OptionsMoves "Movimientos" 0 {Opciones de la entrada de movimientos}
@@ -502,6 +504,8 @@ translate S readonly {slo lectura}
 translate S altered {alterado}
 translate S tagsDescript {Etiquetas adicionales (p.e.: Annotator "Anand")}
 translate S prevTags {Usar el anterior}
+# ====== TODO To be translated ======
+translate S value {Value}
 
 # Standard error messages:
 translate S ErrNotOpen {Esta base de datos no est abierta.}
@@ -765,6 +769,8 @@ translate S AnnotateBlundersOnly {Cuando el movimiento es un disparate}
 translate S BlundersNotBest {Fallo/No Mejor}
 translate S AnnotateTitle {Configurar anotacin}
 translate S AnnotateMissedMates {Mates omitidos/ms cortos}
+# ====== TODO To be translated ======
+translate S AnnotateEnd {At end of game}
 translate S BlundersThreshold {(Umbral)}
 translate S ScoreFormat {Formato de puntuacin}
 translate S CutOff {Corte}
@@ -1186,6 +1192,8 @@ translate S ChangeTextDialog {Enabling text colour globally requires restart.}
 # ====== TODO To be translated ======
 translate S ChangeDockDialog {Changing Docking requires a restart.}
 # ====== TODO To be translated ======
+translate S FontSelectDialog "This is some sample text\nDouble click above to change font, then select 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
+# ====== TODO To be translated ======
 translate S ExitNow {Exit now ?}
 
 # Import window:
@@ -1271,6 +1279,8 @@ translate S OprepTheoryTable {Tabla Terica}
 translate S OprepTableComment {Generado a partir de las %u partidas con mejor Elo.}
 translate S OprepExtraMoves {Anotacin extra de movimientos en la tabla terica}
 translate S OprepMaxGames {Mximas partidas en la tabla terica}
+# ====== TODO To be translated ======
+translate S OprepMaxLines {Maximum games for statistics}
 translate S OprepViewHTML {Ver HTML}
 translate S OprepViewLaTeX {Ver LaTeX}
 
@@ -1374,6 +1384,8 @@ translate S ExportComments {Exportar comentarios?}
 translate S ExportVariations {Exportar variaciones?}
 translate S IndentComments {Sangrar comentarios?}
 translate S IndentVariations {Sangrar variaciones?}
+# ====== TODO To be translated ======
+translate S InsertNewlines {Insert newlines every 80 chars?}
 translate S ExportColumnStyle {Estilo de columna (un movimiento por lnea)?}
 translate S ExportSymbolStyle {Estilo de anotacin simblico:}
 translate S ExportStripMarks {Quitar marca de cdigos de casilla/flecha de los comentarios?}
@@ -1534,6 +1546,8 @@ translate S WinWonGame {Gana la partida ganada}
 translate S Lines {Lneas}
 translate S ConfigureUCIengine {Configurar motor}
 translate S SpecificOpening {Apertura especfica}
+# ====== TODO To be translated ======
+translate S ImportECO {Import ECO}
 translate S StartNewGame {Empezar partida nueva}
 translate S FixedLevel {Nivel fijado}
 translate S Opening {Abriendo}
