@@ -29,8 +29,7 @@ namespace eval tactics {
   # set labelSolution {. . . . . . }
   set lastGameLoaded 0
   set prevFen ""
-  ### This used to be significant, but now is dynamic, according to which slot "toga" has
-  # set engineSlot 5
+
   # Don't try to find the exact best move but to win a won game (that is a mate in 5 is ok even if there was a pending mate in 2)
   set winWonGame 0
 
@@ -51,34 +50,51 @@ namespace eval tactics {
     set found 0
 
     if {![sc_base inUse] || [sc_base numGames] == 0} {
-      tk_messageBox -type ok -icon info -title {Find Best Move} -message "No games in database"      
+      tk_messageBox -type ok -icon info -title {Find Best Move} -message "No games in database"     
       return
     }
-
+   
+    busyCursor .
+    update
+   
     # Try to find in current game, from current pos (exit vars first)
-    catch { ;# if gamenumber == 0, sc_game flag T returns no boolean
+    catch {
+      # if gamenumber == 0, sc_game flag T returns no boolean
       if {[sc_game flag T [sc_game number]]} {
 	while {[sc_var level] != 0} { sc_var exit }
-	if {[llength [gotoNextTacticMarker] ] != 0} {
-	  set found 1
-	}
+	  if {[llength [gotoNextTacticMarker] ] != 0} {
+	    set found 1
+	  }
       }
     }
 
     if {!$found} {
+      # Then search other 'T' flagged games in DB
       for {set g [expr [sc_game number] +1] } { $g <= [sc_base numGames]} { incr g} {
+        if {![sc_game flag T $g]} {
+          continue
+        }
         sc_game load $g
-        if {![sc_game flag T $g]} { continue }
-        # go through all moves and look for tactical markers ****
+        # go through all moves and look for tactical markers ****D->
         if {[llength [gotoNextTacticMarker] ] != 0} {
           set found 1
           break
+        } else {
+          # A tactical flagged game (without ****D-> markers) with non-standard start position,
+	  # begins probably with a tactical position.
+          if {[sc_game startBoard]} {
+	    sc_move start
+            set found 1
+            break
+          }
         }
       }
     }
-
+   
+    unbusyCursor .
+   
     if { ! $found } {
-      tk_messageBox -type ok -icon info -title {Find Best Move} -message "No (more) relevant games found."      
+      tk_messageBox -type ok -icon info -title {Find Best Move} -message "No (more) relevant games found."     
       sc_game load 1
     } else  {
       sideToMoveAtBottom
@@ -97,10 +113,6 @@ namespace eval tactics {
       sc_move forward
       set cmt [sc_pos getComment]
 
-      ### Only matches ****D at start of line, but annotation feature now puts scores at start of line
-      # set res [scan $cmt "\*\*\*\*D%d %f->%f" dif prevscore score ]
-      # if {$res == 3} { return [list $dif $score $prevscore] }
-
       if {[string match {*\*\*\*\*D*->*} $cmt]} {
         # anything non-null
         return $cmt
@@ -109,6 +121,7 @@ namespace eval tactics {
     return {}
   }
 
+
   ### Configuration dialog for Mate in N puzzle
   # (Had some associated core dumps here, possibly when scidBasesDir is wrongly set in config S.A)
 
@@ -116,9 +129,8 @@ namespace eval tactics {
     global ::tactics::basePath ::tactics::baseList ::tactics::baseDesc
     set basePath $::scidBasesDir
 
-    set w .tacticsWin
-    if {[winfo exists $w]} {
-      destroy $w
+    if {[winfo exists .tacticsWin]} {
+      destroy .tacticsWin
     }
 
     set w .configTactics
@@ -126,13 +138,14 @@ namespace eval tactics {
       raiseWin $w
       return
     }
+
     update
     toplevel $w
     wm title $w $::tr(ConfigureTactics)
     setWinLocation $w
 
     if {[sc_base count free] == 0} {
-      tk_messageBox -type ok -icon info -title "Scid" -message "Too many databases are open; close one first"
+      tk_messageBox -type ok -icon info -title Scid -message "Too many databases are open; close one first"
       return
     }
 
@@ -175,7 +188,7 @@ namespace eval tactics {
 
     listbox $w.fconfig.flist.lb -selectmode single -exportselection 0 \
         -yscrollcommand "$w.fconfig.flist.ybar set" -height 10 -width 30
-    bind $w.fconfig.flist.lb <Double-Button-1> ::tactics::start
+    bind $w.fconfig.flist.lb <Double-Button-1> "::tactics::start $w"
 
     scrollbar $w.fconfig.flist.ybar -command "$w.fconfig.flist.lb yview"
     pack $w.fconfig.flist.lb $w.fconfig.flist.ybar -side left -fill y
@@ -191,7 +204,7 @@ namespace eval tactics {
       set desc [lindex $::tactics::baseDesc $current]
       if {[tk_messageBox -type yesno -parent .configTactics -icon question \
 	     -title {Confirm Reset} -message "Confirm resetting \"$desc\" database"] == {yes}} {
-	::tactics::resetScores $name
+	::tactics::resetScores $name .configTactics
       }
     }
     pack $w.fconfig.reset.button
@@ -205,7 +218,7 @@ namespace eval tactics {
     pack $w.fconfig.flimit.analysisTime -side bottom
 
     frame $w.fconfig.fbutton
-    dialogbutton $w.fconfig.fbutton.ok -text Ok -command ::tactics::start
+    dialogbutton $w.fconfig.fbutton.ok -text Ok -command "::tactics::start $w"
     dialogbutton $w.fconfig.fbutton.cancel -text $::tr(Cancel) -command "focus .main ; destroy $w"
     pack $w.fconfig.fbutton.ok $w.fconfig.fbutton.cancel -expand yes -side left -padx 20 -pady 2
     pack $w.fconfig $w.fconfig.flist $w.fconfig.reset -side top
@@ -221,16 +234,19 @@ namespace eval tactics {
     bind $w <F1> { helpWindow TacticsTrainer }
   }
 
-  ################################################################################
-  #
-  ################################################################################
-  proc start {} {
+
+  proc start {parent} {
     global ::tactics::analysisEngine ::askToReplaceMoves ::tactics::askToReplaceMoves_old
 
     set current [.configTactics.fconfig.flist.lb curselection]
     set base [lindex $::tactics::baseList [expr $current * 2]]
     set desc [lindex $::tactics::baseDesc $current]
-    destroy .configTactics
+
+    if {![::tactics::loadBase [file rootname $base] $parent]} {
+      return
+    }
+
+    destroy $parent
 
     set ::gameInfo(hideNextMove) 1
     if {[winfo exists .pgnWin]} {
@@ -293,8 +309,6 @@ namespace eval tactics {
     bind $w <Configure> "recordWinSize $w"
     bind $w <F1> { helpWindow TacticsTrainer }
 
-    ::tactics::loadBase [file rootname $base]
-
     setInfoEngine "---"
     ::tactics::loadNextGame
     ::tactics::mainLoop
@@ -317,9 +331,7 @@ namespace eval tactics {
 
     catch { ::uci::closeUCIengine $::tactics::engineSlot }
   }
-  ################################################################################
-  #
-  ################################################################################
+
   proc toggleSolution {} {
     global ::tactics::showSolution ::tactics::labelSolution ::tactics::analysisEngine
 
@@ -350,10 +362,7 @@ namespace eval tactics {
     update
   }
 
-  ################################################################################
-  #
-  ################################################################################
-  proc resetScores {name} {
+  proc resetScores {name parent} {
     global ::tactics::cancelScoreReset ::tactics::baseList
 
     set base [file rootname $name]
@@ -361,7 +370,7 @@ namespace eval tactics {
     set wasOpened 0
 
     if {[sc_base count free] == 0} {
-      tk_messageBox -type ok -icon info -title "Scid" -message "Too many databases are opened\nClose one first"
+      tk_messageBox -type ok -icon info -title Scid -message "Too many databases are opened\nClose one first" -parent $parent
       return
     }
     # check if the base is already opened
@@ -370,13 +379,17 @@ namespace eval tactics {
       set wasOpened 1
     } else  {
       if { [catch { sc_base open $base }] } {
-        tk_messageBox -type ok -icon warning -title "Scid" -message "Unable to open base"
+        tk_messageBox -type ok -icon warning -title Scid -message "Unable to open base" -parent $parent
         return
       }
     }
+    if {[sc_base isReadOnly]} {
+        tk_messageBox -type ok -icon warning -title Scid -message "Base $base is read-only" -parent $parent
+        return
+    }
 
     # reset site tag for each game
-    progressWindow "Scid" $::tr(ResettingScore) $::tr(Cancel) "::tactics::sc_progressBar"
+    progressWindow Scid $::tr(ResettingScore) $::tr(Cancel) "::tactics::sc_progressBar"
     set numGames [sc_base numGames]
     set cancelScoreReset 0
     for {set g 1} { $g <= $numGames } { incr g} {
@@ -428,7 +441,7 @@ namespace eval tactics {
     }
     # it seems we finished the serial
     if {! $newGameFound } {
-      tk_messageBox -title "Scid" -icon info -type ok -message $::tr(AllExercisesDone)
+      tk_messageBox -title Scid -icon info -type ok -message $::tr(AllExercisesDone)
       return
     }
     set ::tactics::lastGameLoaded $g
@@ -440,7 +453,6 @@ namespace eval tactics {
 
     updateBoard -pgn
     set ::tactics::prevFen [sc_pos fen]
-    ::windows::gamelist::Refresh
     ::tree::refresh
     ::windows::stats::Refresh
     updateMenuStates
@@ -483,7 +495,7 @@ namespace eval tactics {
     if {$::tactics::showSolution} {
       return
     }
-    tk_messageBox -title "Scid" -icon info -type ok -message $::tr(MateFound)
+    tk_messageBox -title Scid -icon info -type ok -message $::tr(MateFound)
     ::tactics::loadNextGame
   }
   ################################################################################
@@ -493,7 +505,6 @@ namespace eval tactics {
   proc abnormalContinuation {} {
     ::tactics::stopAnalyze
     ::tactics::resetValues
-    ::windows::gamelist::Refresh
     ::tree::refresh
     ::windows::stats::Refresh
     updateMenuStates
@@ -557,7 +568,7 @@ namespace eval tactics {
     # compare results
     set res [::tactics::foundBestLine]
     if {  $res != ""} {
-      tk_messageBox -title "Scid" -icon info -type ok -message "$::tr(BestSolutionNotFound)\n$res"
+      tk_messageBox -title Scid -icon info -type ok -message "$::tr(BestSolutionNotFound)\n$res"
       # take back last move so restore engine status
       set analysisEngine(score) $prevScore
       set analysisEngine(moves) $prevLine
@@ -610,10 +621,6 @@ namespace eval tactics {
       set matePending 1
       #  Engine may find a mate then put a score != 300 but rather 10
       if {[string index $line end] != "#"} {
-        # Engine line does not end with a # but the score is a mate (we can't count plies here)
-        if {[sc_pos side] == "white" && $score < -300 || [sc_pos side] == "black" && $score > 300} {
-          return ""
-        }
         if {! $::tactics::winWonGame } {
           return $::tr(MateNotFound)
         } else  {
@@ -662,29 +669,33 @@ namespace eval tactics {
   ################################################################################
   # Loads a base bundled with Scid (in ./bases directory)
   ################################################################################
-  proc loadBase { name } {
+  proc loadBase {name parent} {
 
     if {[sc_base count free] == 0} {
-      tk_messageBox -type ok -icon info -title "Scid" -message "Too many databases are open; close one first"
-      return
+      tk_messageBox -type ok -icon info -title Scid -message "Too many databases are open; close one first" -parent $parent
+      return 0
     }
     # check if the base is already opened
     if {[sc_base slot $name] != 0} {
       sc_base switch [sc_base slot $name]
     } else  {
       if { [catch { sc_base open $name }] } {
-        tk_messageBox -type ok -icon warning -title "Scid" -message "Unable to open base"
-        return
+        tk_messageBox -type ok -icon warning -title Scid -message "Unable to open base" -parent $parent
+        return 0
       }
     }
+    if {[sc_base isReadOnly]} {
+        tk_messageBox -type ok -icon warning -title Scid -message "Base $name is read-only" -parent $parent
+        return 0
+    }
 
-    ::windows::gamelist::Refresh
     ::tree::refresh
     ::windows::stats::Refresh
     updateMenuStates
     updateBoard -pgn
     updateTitle
     updateStatusBar
+    return 1
   }
 
   ################################################################################
@@ -731,7 +742,7 @@ namespace eval tactics {
       if { [string equal -nocase -length 4 [lindex $e 0] "toga" ] } {
 	# Start engine in analysis mode
         set ::tactics::engineSlot $index
-	::uci::startEngine $index
+	::uci::startSilentEngine $index
 	return 1
       }
       incr index
@@ -740,7 +751,7 @@ namespace eval tactics {
     # failsafe only ???
     set ::tactics::engineSlot 0
 
-    tk_messageBox -type ok -icon warning -parent . -title "Scid" \
+    tk_messageBox -type ok -icon warning -parent . -title Scid \
       -message "Unable to find engine.\nPlease configure engine with Toga as name"
     return 0
 
