@@ -779,6 +779,10 @@ proc changeBaseType {baseNum {parent .}} {
   set temp_dbtype [sc_base type $baseNum]
   if {$temp_dbtype >= $numBaseTypeIcons} { set temp_dbtype 0 }
   set w .btypeWin
+  if {[winfo exists $w]} {
+    raiseWin $w
+    return
+  }
   toplevel $w
   wm withdraw $w
   wm title $w "Choose database type"
@@ -829,10 +833,7 @@ proc changeBaseType {baseNum {parent .}} {
 
   placeWinOverParent $w $parent
   wm state $w normal
-
   focus $w.t
-  grab $w
-  update
   selectBaseType $temp_dbtype
 }
 
@@ -956,12 +957,14 @@ proc ::windows::switcher::Open {} {
       $f.menu.show add command -label WindowsTree  -command "::tree::Open $i"
       $f.menu.show add command -label TreeFileBest -command "::tree::OpenBest $i"
       $f.menu.show add separator
-      $f.menu.show add command -label LoadFilter  -command "loadFilter $i"
-      $f.menu.show add command -label SaveFile -command "saveFilter $i"
+      $f.menu.show add command -label "[tr LoadGame] [tr Filter]"  -command "loadFilter $i"
+      $f.menu.show add command -label "[tr Save] [tr Filter]" -command "saveFilter $i"
       $f.menu.show add separator
-      $f.menu.show add command -label [tr ChangeIcon] -command "changeBaseType $i $w"
+      $f.menu.show add command -label [tr ChangeIcon] -command "changeBaseType $i .glistWin"
       $f.menu.show add checkbutton -label [tr ShowIcons] -variable ::windows::switcher::icons -command ::windows::switcher::Refresh
       $f.menu.show add checkbutton -label [tr ConfirmCopy] -variable ::windows::switcher::confirmCopy 
+      $f.menu.show add separator
+      $f.menu.show add checkbutton -label [tr TreeOptShowFrame] -variable ::windows::gamelist::showButtons -command ::windows::gamelist::displayButtons
 
       configMenuText $f.menu.show 0 WindowsTree  $::language
       configMenuText $f.menu.show 1 TreeFileBest $::language
